## Summary

Multiple independent websites can automatically generate both a PDF file and an HTML page from a baseprint digitally encoded in JATS XML. JATS XML is often used to encode journal articles published in both PDF and HTML formats, many of which appear on both the publisher’s website and PubMed Central, a US government agency website for scientific literature.

Baseprints provide features of preprints and blog posts through the generation of PDF files and HTML pages. The following table summarizes the advantages of baseprints over PDF preprints and blog posts:

Feature | PDF preprint | Blog post | JATS XML | Baseprint
--- | --- | --- | --- | ---
Designed for different displays |  | Yes | Yes | Yes
Clone documents across multiple websites | Yes |  |  | Yes
Document metadata like journal articles |  |  | Yes | Yes
Target of intrinsic identifier |  |  |  | Yes